@@ -2,7 +2,7 @@
 
 use FindBin;
 BEGIN {
-    my $env = "$FindBin::Bin/script/env";
+    my $env = "$FindBin::Bin/env";
     if (-r $env) {
         do $env or die $@;
     }
